@@ -2,7 +2,7 @@
 
 use once_cell::sync::OnceCell;
 
-mod utils;
+pub mod utils;
 
 /*
 LateInit allows for delayed initialization of struct fields exactly once, making
